# coding: utf-8

"""
    Robust Intelligence REST API

    API methods for Robust Intelligence. Users must authenticate using the `rime-api-key` header.  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: dev@robustintelligence.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class RuntimeinfoRunTimeInfo(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'custom_image': 'RuntimeinfoCustomImageType',
        'resource_request': 'RuntimeinfoResourceRequest',
        'explicit_errors': 'bool',
        'random_seed': 'str'
    }

    attribute_map = {
        'custom_image': 'customImage',
        'resource_request': 'resourceRequest',
        'explicit_errors': 'explicitErrors',
        'random_seed': 'randomSeed'
    }

    def __init__(self, custom_image=None, resource_request=None, explicit_errors=None, random_seed=None):  # noqa: E501
        """RuntimeinfoRunTimeInfo - a model defined in Swagger"""  # noqa: E501
        self._custom_image = None
        self._resource_request = None
        self._explicit_errors = None
        self._random_seed = None
        self.discriminator = None
        if custom_image is not None:
            self.custom_image = custom_image
        if resource_request is not None:
            self.resource_request = resource_request
        if explicit_errors is not None:
            self.explicit_errors = explicit_errors
        if random_seed is not None:
            self.random_seed = random_seed

    @property
    def custom_image(self):
        """Gets the custom_image of this RuntimeinfoRunTimeInfo.  # noqa: E501


        :return: The custom_image of this RuntimeinfoRunTimeInfo.  # noqa: E501
        :rtype: RuntimeinfoCustomImageType
        """
        return self._custom_image

    @custom_image.setter
    def custom_image(self, custom_image):
        """Sets the custom_image of this RuntimeinfoRunTimeInfo.


        :param custom_image: The custom_image of this RuntimeinfoRunTimeInfo.  # noqa: E501
        :type: RuntimeinfoCustomImageType
        """

        self._custom_image = custom_image

    @property
    def resource_request(self):
        """Gets the resource_request of this RuntimeinfoRunTimeInfo.  # noqa: E501


        :return: The resource_request of this RuntimeinfoRunTimeInfo.  # noqa: E501
        :rtype: RuntimeinfoResourceRequest
        """
        return self._resource_request

    @resource_request.setter
    def resource_request(self, resource_request):
        """Sets the resource_request of this RuntimeinfoRunTimeInfo.


        :param resource_request: The resource_request of this RuntimeinfoRunTimeInfo.  # noqa: E501
        :type: RuntimeinfoResourceRequest
        """

        self._resource_request = resource_request

    @property
    def explicit_errors(self):
        """Gets the explicit_errors of this RuntimeinfoRunTimeInfo.  # noqa: E501

        Specifies whether the job will return silent errors. By default, this is set to false, and silent errors are not returned.  # noqa: E501

        :return: The explicit_errors of this RuntimeinfoRunTimeInfo.  # noqa: E501
        :rtype: bool
        """
        return self._explicit_errors

    @explicit_errors.setter
    def explicit_errors(self, explicit_errors):
        """Sets the explicit_errors of this RuntimeinfoRunTimeInfo.

        Specifies whether the job will return silent errors. By default, this is set to false, and silent errors are not returned.  # noqa: E501

        :param explicit_errors: The explicit_errors of this RuntimeinfoRunTimeInfo.  # noqa: E501
        :type: bool
        """

        self._explicit_errors = explicit_errors

    @property
    def random_seed(self):
        """Gets the random_seed of this RuntimeinfoRunTimeInfo.  # noqa: E501

        Random seed to use for the Job, so that Test Job result will be deterministic.  # noqa: E501

        :return: The random_seed of this RuntimeinfoRunTimeInfo.  # noqa: E501
        :rtype: str
        """
        return self._random_seed

    @random_seed.setter
    def random_seed(self, random_seed):
        """Sets the random_seed of this RuntimeinfoRunTimeInfo.

        Random seed to use for the Job, so that Test Job result will be deterministic.  # noqa: E501

        :param random_seed: The random_seed of this RuntimeinfoRunTimeInfo.  # noqa: E501
        :type: str
        """

        self._random_seed = random_seed

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(RuntimeinfoRunTimeInfo, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RuntimeinfoRunTimeInfo):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



"""Script for firewall auth before using the SDK."""

import webbrowser
from http.server import HTTPServer, SimpleHTTPRequestHandler
from urllib.parse import parse_qs, urlparse

_stop = False


class Serv(SimpleHTTPRequestHandler):
    """Local HTTP server for saving auth token."""

    def _set_headers(self) -> None:
        self.send_response(200)
        self.send_header("Content-type", "text/html")
        self.end_headers()

    def _html(self, message: str) -> bytes:
        content = f"<html><body><h1>{message}</h1></body></html>"
        return content.encode("utf8")  # NOTE: must return a bytes object!

    def do_GET(self) -> None:  # noqa: N802
        """Handle GET API call."""
        query_components = parse_qs(urlparse(self.path).query)
        if "authToken" in query_components:
            token = query_components["authToken"]
            with open("./token.txt", "w") as file:
                file.write(token[0])
            self._set_headers()
            self.wfile.write(self._html("Authenticated!"))
            global _stop
            _stop = True
        else:
            self.wfile.write(self._html("Not Authenticated!"))
            _stop = True


class StoppableHttpServer(HTTPServer):
    """HTTP server that can be stopped."""

    def serve_forever(self, poll_interval: float = 0.5) -> None:  # noqa: ARG002
        """Handle one request at a time until stopped."""
        while not _stop:
            self.handle_request()


class Authenticator:
    """Firewall authenticator."""

    @staticmethod
    def _prepare_url(host_url: str, email: str, system_account: bool = False) -> str:
        """Prepare the url for auth endpoint."""
        baseurl = host_url + "/v1/auth/authenticate"
        url = (
            baseurl
            + "?"
            + "email="
            + email
            + "&"
            + "system_account="
            + str(system_account)
        )
        return url

    def auth(self, host_url: str, email: str, system_account: bool = False) -> None:
        """Auth method in firewall sdk."""
        url = self._prepare_url(host_url, email, system_account)
        webbrowser.open_new_tab(url)
        httpd = StoppableHttpServer(("localhost", 8099), Serv)
        httpd.serve_forever()



# coding: utf-8

"""
    Robust Intelligence REST API

    API methods for Robust Intelligence. Users must authenticate using the `rime-api-key` header.  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: dev@robustintelligence.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from rime_sdk.swagger.swagger_client.api_client import ApiClient


class WorkspaceServiceApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def workspace_service_add_users_to_workspace(self, body, workspace_id_uuid, **kwargs):  # noqa: E501
        """AddUsersToWorkspace  # noqa: E501

        Grants Users permissions to a Workspace.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.workspace_service_add_users_to_workspace(body, workspace_id_uuid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param WorkspaceIdUuidUsersBody body: (required)
        :param str workspace_id_uuid: Unique object ID. (required)
        :return: RimeAddUsersToWorkspaceResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.workspace_service_add_users_to_workspace_with_http_info(body, workspace_id_uuid, **kwargs)  # noqa: E501
        else:
            (data) = self.workspace_service_add_users_to_workspace_with_http_info(body, workspace_id_uuid, **kwargs)  # noqa: E501
            return data

    def workspace_service_add_users_to_workspace_with_http_info(self, body, workspace_id_uuid, **kwargs):  # noqa: E501
        """AddUsersToWorkspace  # noqa: E501

        Grants Users permissions to a Workspace.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.workspace_service_add_users_to_workspace_with_http_info(body, workspace_id_uuid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param WorkspaceIdUuidUsersBody body: (required)
        :param str workspace_id_uuid: Unique object ID. (required)
        :return: RimeAddUsersToWorkspaceResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'workspace_id_uuid']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method workspace_service_add_users_to_workspace" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `workspace_service_add_users_to_workspace`")  # noqa: E501
        # verify the required parameter 'workspace_id_uuid' is set
        if ('workspace_id_uuid' not in params or
                params['workspace_id_uuid'] is None):
            raise ValueError("Missing the required parameter `workspace_id_uuid` when calling `workspace_service_add_users_to_workspace`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'workspace_id_uuid' in params:
            path_params['workspaceId.uuid'] = params['workspace_id_uuid']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Firewall-Api-Key', 'X-Firewall-Auth-Token', 'rime-api-key']  # noqa: E501

        return self.api_client.call_api(
            '/v1/workspace/{workspaceId.uuid}/users', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='RimeAddUsersToWorkspaceResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def workspace_service_create_workspace(self, body, **kwargs):  # noqa: E501
        """CreateWorkspace  # noqa: E501

        Create a new Workspace.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.workspace_service_create_workspace(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param RimeCreateWorkspaceRequest body: (required)
        :return: RimeCreateWorkspaceResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.workspace_service_create_workspace_with_http_info(body, **kwargs)  # noqa: E501
        else:
            (data) = self.workspace_service_create_workspace_with_http_info(body, **kwargs)  # noqa: E501
            return data

    def workspace_service_create_workspace_with_http_info(self, body, **kwargs):  # noqa: E501
        """CreateWorkspace  # noqa: E501

        Create a new Workspace.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.workspace_service_create_workspace_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param RimeCreateWorkspaceRequest body: (required)
        :return: RimeCreateWorkspaceResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method workspace_service_create_workspace" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `workspace_service_create_workspace`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Firewall-Api-Key', 'X-Firewall-Auth-Token', 'rime-api-key']  # noqa: E501

        return self.api_client.call_api(
            '/v1/workspace', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='RimeCreateWorkspaceResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def workspace_service_delete_workspace(self, workspace_id_uuid, **kwargs):  # noqa: E501
        """DeleteWorkspace  # noqa: E501

        Deletes an existing Workspace by ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.workspace_service_delete_workspace(workspace_id_uuid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str workspace_id_uuid: Unique object ID. (required)
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.workspace_service_delete_workspace_with_http_info(workspace_id_uuid, **kwargs)  # noqa: E501
        else:
            (data) = self.workspace_service_delete_workspace_with_http_info(workspace_id_uuid, **kwargs)  # noqa: E501
            return data

    def workspace_service_delete_workspace_with_http_info(self, workspace_id_uuid, **kwargs):  # noqa: E501
        """DeleteWorkspace  # noqa: E501

        Deletes an existing Workspace by ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.workspace_service_delete_workspace_with_http_info(workspace_id_uuid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str workspace_id_uuid: Unique object ID. (required)
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['workspace_id_uuid']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method workspace_service_delete_workspace" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'workspace_id_uuid' is set
        if ('workspace_id_uuid' not in params or
                params['workspace_id_uuid'] is None):
            raise ValueError("Missing the required parameter `workspace_id_uuid` when calling `workspace_service_delete_workspace`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'workspace_id_uuid' in params:
            path_params['workspaceId.uuid'] = params['workspace_id_uuid']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Firewall-Api-Key', 'X-Firewall-Auth-Token', 'rime-api-key']  # noqa: E501

        return self.api_client.call_api(
            '/v1/workspace/{workspaceId.uuid}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='object',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def workspace_service_get_workspace(self, workspace_id_uuid, **kwargs):  # noqa: E501
        """GetWorkspace  # noqa: E501

        Return a Workspace by ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.workspace_service_get_workspace(workspace_id_uuid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str workspace_id_uuid: Unique object ID. (required)
        :return: RimeGetWorkspaceResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.workspace_service_get_workspace_with_http_info(workspace_id_uuid, **kwargs)  # noqa: E501
        else:
            (data) = self.workspace_service_get_workspace_with_http_info(workspace_id_uuid, **kwargs)  # noqa: E501
            return data

    def workspace_service_get_workspace_with_http_info(self, workspace_id_uuid, **kwargs):  # noqa: E501
        """GetWorkspace  # noqa: E501

        Return a Workspace by ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.workspace_service_get_workspace_with_http_info(workspace_id_uuid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str workspace_id_uuid: Unique object ID. (required)
        :return: RimeGetWorkspaceResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['workspace_id_uuid']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method workspace_service_get_workspace" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'workspace_id_uuid' is set
        if ('workspace_id_uuid' not in params or
                params['workspace_id_uuid'] is None):
            raise ValueError("Missing the required parameter `workspace_id_uuid` when calling `workspace_service_get_workspace`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'workspace_id_uuid' in params:
            path_params['workspaceId.uuid'] = params['workspace_id_uuid']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Firewall-Api-Key', 'X-Firewall-Auth-Token', 'rime-api-key']  # noqa: E501

        return self.api_client.call_api(
            '/v1/workspace/{workspaceId.uuid}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='RimeGetWorkspaceResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def workspace_service_list_project_tags_in_workspace(self, workspace_id_uuid, **kwargs):  # noqa: E501
        """ListProjectTagsInWorkspace  # noqa: E501

        List the union of all tags in all projects in the workspace  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.workspace_service_list_project_tags_in_workspace(workspace_id_uuid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str workspace_id_uuid: Unique object ID. (required)
        :return: RimeListProjectTagsInWorkspaceResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.workspace_service_list_project_tags_in_workspace_with_http_info(workspace_id_uuid, **kwargs)  # noqa: E501
        else:
            (data) = self.workspace_service_list_project_tags_in_workspace_with_http_info(workspace_id_uuid, **kwargs)  # noqa: E501
            return data

    def workspace_service_list_project_tags_in_workspace_with_http_info(self, workspace_id_uuid, **kwargs):  # noqa: E501
        """ListProjectTagsInWorkspace  # noqa: E501

        List the union of all tags in all projects in the workspace  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.workspace_service_list_project_tags_in_workspace_with_http_info(workspace_id_uuid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str workspace_id_uuid: Unique object ID. (required)
        :return: RimeListProjectTagsInWorkspaceResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['workspace_id_uuid']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method workspace_service_list_project_tags_in_workspace" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'workspace_id_uuid' is set
        if ('workspace_id_uuid' not in params or
                params['workspace_id_uuid'] is None):
            raise ValueError("Missing the required parameter `workspace_id_uuid` when calling `workspace_service_list_project_tags_in_workspace`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'workspace_id_uuid' in params:
            path_params['workspaceId.uuid'] = params['workspace_id_uuid']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Firewall-Api-Key', 'X-Firewall-Auth-Token', 'rime-api-key']  # noqa: E501

        return self.api_client.call_api(
            '/v1/workspace/{workspaceId.uuid}/tags/project', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='RimeListProjectTagsInWorkspaceResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def workspace_service_list_users_of_workspace(self, workspace_id_uuid, **kwargs):  # noqa: E501
        """ListUsersOfWorkspace  # noqa: E501

        Lists all Users that have permissions to a Workspace.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.workspace_service_list_users_of_workspace(workspace_id_uuid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str workspace_id_uuid: Unique object ID. (required)
        :param str page_token: Specifies a page of the list returned by a ListUsersOfWorkspace query. The ListUsersOfWorkspace query returns a pageToken when there is more than one page of results.
        :param str page_size: The maximum number of User objects to return in a single page.
        :return: RimeListUsersOfWorkspaceResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.workspace_service_list_users_of_workspace_with_http_info(workspace_id_uuid, **kwargs)  # noqa: E501
        else:
            (data) = self.workspace_service_list_users_of_workspace_with_http_info(workspace_id_uuid, **kwargs)  # noqa: E501
            return data

    def workspace_service_list_users_of_workspace_with_http_info(self, workspace_id_uuid, **kwargs):  # noqa: E501
        """ListUsersOfWorkspace  # noqa: E501

        Lists all Users that have permissions to a Workspace.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.workspace_service_list_users_of_workspace_with_http_info(workspace_id_uuid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str workspace_id_uuid: Unique object ID. (required)
        :param str page_token: Specifies a page of the list returned by a ListUsersOfWorkspace query. The ListUsersOfWorkspace query returns a pageToken when there is more than one page of results.
        :param str page_size: The maximum number of User objects to return in a single page.
        :return: RimeListUsersOfWorkspaceResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['workspace_id_uuid', 'page_token', 'page_size']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method workspace_service_list_users_of_workspace" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'workspace_id_uuid' is set
        if ('workspace_id_uuid' not in params or
                params['workspace_id_uuid'] is None):
            raise ValueError("Missing the required parameter `workspace_id_uuid` when calling `workspace_service_list_users_of_workspace`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'workspace_id_uuid' in params:
            path_params['workspaceId.uuid'] = params['workspace_id_uuid']  # noqa: E501

        query_params = []
        if 'page_token' in params:
            query_params.append(('pageToken', params['page_token']))  # noqa: E501
        if 'page_size' in params:
            query_params.append(('pageSize', params['page_size']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Firewall-Api-Key', 'X-Firewall-Auth-Token', 'rime-api-key']  # noqa: E501

        return self.api_client.call_api(
            '/v1/workspace/{workspaceId.uuid}/users', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='RimeListUsersOfWorkspaceResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def workspace_service_list_workspaces(self, **kwargs):  # noqa: E501
        """ListWorkspaces  # noqa: E501

        List Workspaces with optional filter.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.workspace_service_list_workspaces(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str page_size: The maximum number of Workspace objects to return in a single page.
        :param str page_token: Specifies a page of the list returned by a ListWorkspaces query. The ListWorkspaces query returns a pageToken when there is more than one page of results.
        :return: RimeListWorkspacesResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.workspace_service_list_workspaces_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.workspace_service_list_workspaces_with_http_info(**kwargs)  # noqa: E501
            return data

    def workspace_service_list_workspaces_with_http_info(self, **kwargs):  # noqa: E501
        """ListWorkspaces  # noqa: E501

        List Workspaces with optional filter.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.workspace_service_list_workspaces_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str page_size: The maximum number of Workspace objects to return in a single page.
        :param str page_token: Specifies a page of the list returned by a ListWorkspaces query. The ListWorkspaces query returns a pageToken when there is more than one page of results.
        :return: RimeListWorkspacesResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['page_size', 'page_token']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method workspace_service_list_workspaces" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'page_size' in params:
            query_params.append(('pageSize', params['page_size']))  # noqa: E501
        if 'page_token' in params:
            query_params.append(('pageToken', params['page_token']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Firewall-Api-Key', 'X-Firewall-Auth-Token', 'rime-api-key']  # noqa: E501

        return self.api_client.call_api(
            '/v1/workspace', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='RimeListWorkspacesResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def workspace_service_remove_user_from_workspace(self, workspace_id_uuid, user_id_uuid, **kwargs):  # noqa: E501
        """RemoveUserFromWorkspace  # noqa: E501

        Removes a User from a Workspace.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.workspace_service_remove_user_from_workspace(workspace_id_uuid, user_id_uuid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str workspace_id_uuid: Unique object ID. (required)
        :param str user_id_uuid: Unique object ID. (required)
        :return: RimeRemoveUserFromWorkspaceResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.workspace_service_remove_user_from_workspace_with_http_info(workspace_id_uuid, user_id_uuid, **kwargs)  # noqa: E501
        else:
            (data) = self.workspace_service_remove_user_from_workspace_with_http_info(workspace_id_uuid, user_id_uuid, **kwargs)  # noqa: E501
            return data

    def workspace_service_remove_user_from_workspace_with_http_info(self, workspace_id_uuid, user_id_uuid, **kwargs):  # noqa: E501
        """RemoveUserFromWorkspace  # noqa: E501

        Removes a User from a Workspace.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.workspace_service_remove_user_from_workspace_with_http_info(workspace_id_uuid, user_id_uuid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str workspace_id_uuid: Unique object ID. (required)
        :param str user_id_uuid: Unique object ID. (required)
        :return: RimeRemoveUserFromWorkspaceResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['workspace_id_uuid', 'user_id_uuid']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method workspace_service_remove_user_from_workspace" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'workspace_id_uuid' is set
        if ('workspace_id_uuid' not in params or
                params['workspace_id_uuid'] is None):
            raise ValueError("Missing the required parameter `workspace_id_uuid` when calling `workspace_service_remove_user_from_workspace`")  # noqa: E501
        # verify the required parameter 'user_id_uuid' is set
        if ('user_id_uuid' not in params or
                params['user_id_uuid'] is None):
            raise ValueError("Missing the required parameter `user_id_uuid` when calling `workspace_service_remove_user_from_workspace`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'workspace_id_uuid' in params:
            path_params['workspaceId.uuid'] = params['workspace_id_uuid']  # noqa: E501
        if 'user_id_uuid' in params:
            path_params['userId.uuid'] = params['user_id_uuid']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Firewall-Api-Key', 'X-Firewall-Auth-Token', 'rime-api-key']  # noqa: E501

        return self.api_client.call_api(
            '/v1/workspace/{workspaceId.uuid}/users/{userId.uuid}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='RimeRemoveUserFromWorkspaceResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def workspace_service_update_user_of_workspace(self, body, workspace_id_uuid, user_user_id_uuid, **kwargs):  # noqa: E501
        """UpdateUserOfWorkspace  # noqa: E501

        Updates the permission of a specified User for a Workspace.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.workspace_service_update_user_of_workspace(body, workspace_id_uuid, user_user_id_uuid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param UsersUserUserIdUuidBody1 body: (required)
        :param str workspace_id_uuid: Unique object ID. (required)
        :param str user_user_id_uuid: Unique object ID. (required)
        :return: RimeUpdateUserOfWorkspaceResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.workspace_service_update_user_of_workspace_with_http_info(body, workspace_id_uuid, user_user_id_uuid, **kwargs)  # noqa: E501
        else:
            (data) = self.workspace_service_update_user_of_workspace_with_http_info(body, workspace_id_uuid, user_user_id_uuid, **kwargs)  # noqa: E501
            return data

    def workspace_service_update_user_of_workspace_with_http_info(self, body, workspace_id_uuid, user_user_id_uuid, **kwargs):  # noqa: E501
        """UpdateUserOfWorkspace  # noqa: E501

        Updates the permission of a specified User for a Workspace.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.workspace_service_update_user_of_workspace_with_http_info(body, workspace_id_uuid, user_user_id_uuid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param UsersUserUserIdUuidBody1 body: (required)
        :param str workspace_id_uuid: Unique object ID. (required)
        :param str user_user_id_uuid: Unique object ID. (required)
        :return: RimeUpdateUserOfWorkspaceResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'workspace_id_uuid', 'user_user_id_uuid']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method workspace_service_update_user_of_workspace" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `workspace_service_update_user_of_workspace`")  # noqa: E501
        # verify the required parameter 'workspace_id_uuid' is set
        if ('workspace_id_uuid' not in params or
                params['workspace_id_uuid'] is None):
            raise ValueError("Missing the required parameter `workspace_id_uuid` when calling `workspace_service_update_user_of_workspace`")  # noqa: E501
        # verify the required parameter 'user_user_id_uuid' is set
        if ('user_user_id_uuid' not in params or
                params['user_user_id_uuid'] is None):
            raise ValueError("Missing the required parameter `user_user_id_uuid` when calling `workspace_service_update_user_of_workspace`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'workspace_id_uuid' in params:
            path_params['workspaceId.uuid'] = params['workspace_id_uuid']  # noqa: E501
        if 'user_user_id_uuid' in params:
            path_params['user.userId.uuid'] = params['user_user_id_uuid']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Firewall-Api-Key', 'X-Firewall-Auth-Token', 'rime-api-key']  # noqa: E501

        return self.api_client.call_api(
            '/v1/workspace/{workspaceId.uuid}/users/{user.userId.uuid}', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='RimeUpdateUserOfWorkspaceResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def workspace_service_update_workspace(self, body, workspace_workspace_id_uuid, **kwargs):  # noqa: E501
        """UpdateWorkspace  # noqa: E501

        Updates an existing Workspace by ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.workspace_service_update_workspace(body, workspace_workspace_id_uuid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param WorkspaceWorkspaceWorkspaceIdUuidBody body: (required)
        :param str workspace_workspace_id_uuid: Unique object ID. (required)
        :return: RimeUpdateWorkspaceResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.workspace_service_update_workspace_with_http_info(body, workspace_workspace_id_uuid, **kwargs)  # noqa: E501
        else:
            (data) = self.workspace_service_update_workspace_with_http_info(body, workspace_workspace_id_uuid, **kwargs)  # noqa: E501
            return data

    def workspace_service_update_workspace_with_http_info(self, body, workspace_workspace_id_uuid, **kwargs):  # noqa: E501
        """UpdateWorkspace  # noqa: E501

        Updates an existing Workspace by ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.workspace_service_update_workspace_with_http_info(body, workspace_workspace_id_uuid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param WorkspaceWorkspaceWorkspaceIdUuidBody body: (required)
        :param str workspace_workspace_id_uuid: Unique object ID. (required)
        :return: RimeUpdateWorkspaceResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'workspace_workspace_id_uuid']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method workspace_service_update_workspace" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `workspace_service_update_workspace`")  # noqa: E501
        # verify the required parameter 'workspace_workspace_id_uuid' is set
        if ('workspace_workspace_id_uuid' not in params or
                params['workspace_workspace_id_uuid'] is None):
            raise ValueError("Missing the required parameter `workspace_workspace_id_uuid` when calling `workspace_service_update_workspace`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'workspace_workspace_id_uuid' in params:
            path_params['workspace.workspaceId.uuid'] = params['workspace_workspace_id_uuid']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Firewall-Api-Key', 'X-Firewall-Auth-Token', 'rime-api-key']  # noqa: E501

        return self.api_client.call_api(
            '/v1/workspace/{workspace.workspaceId.uuid}', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='RimeUpdateWorkspaceResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Robust Intelligence REST API

    API methods for Robust Intelligence. Users must authenticate using the `rime-api-key` header.  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: dev@robustintelligence.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class PiiDetectionDetailsFlaggedEntity(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'entity_type': 'GenerativefirewallPiiEntityType',
        'custom_entity_name': 'str',
        'flagged_substring': 'GenerativefirewallFlaggedSubstring',
        'confidence_score': 'float'
    }

    attribute_map = {
        'entity_type': 'entityType',
        'custom_entity_name': 'customEntityName',
        'flagged_substring': 'flaggedSubstring',
        'confidence_score': 'confidenceScore'
    }

    def __init__(self, entity_type=None, custom_entity_name=None, flagged_substring=None, confidence_score=None):  # noqa: E501
        """PiiDetectionDetailsFlaggedEntity - a model defined in Swagger"""  # noqa: E501
        self._entity_type = None
        self._custom_entity_name = None
        self._flagged_substring = None
        self._confidence_score = None
        self.discriminator = None
        if entity_type is not None:
            self.entity_type = entity_type
        if custom_entity_name is not None:
            self.custom_entity_name = custom_entity_name
        if flagged_substring is not None:
            self.flagged_substring = flagged_substring
        if confidence_score is not None:
            self.confidence_score = confidence_score

    @property
    def entity_type(self):
        """Gets the entity_type of this PiiDetectionDetailsFlaggedEntity.  # noqa: E501


        :return: The entity_type of this PiiDetectionDetailsFlaggedEntity.  # noqa: E501
        :rtype: GenerativefirewallPiiEntityType
        """
        return self._entity_type

    @entity_type.setter
    def entity_type(self, entity_type):
        """Sets the entity_type of this PiiDetectionDetailsFlaggedEntity.


        :param entity_type: The entity_type of this PiiDetectionDetailsFlaggedEntity.  # noqa: E501
        :type: GenerativefirewallPiiEntityType
        """

        self._entity_type = entity_type

    @property
    def custom_entity_name(self):
        """Gets the custom_entity_name of this PiiDetectionDetailsFlaggedEntity.  # noqa: E501

        Custom entity name is the name of the custom-defined entity that was detected for this substring, if applicable.  # noqa: E501

        :return: The custom_entity_name of this PiiDetectionDetailsFlaggedEntity.  # noqa: E501
        :rtype: str
        """
        return self._custom_entity_name

    @custom_entity_name.setter
    def custom_entity_name(self, custom_entity_name):
        """Sets the custom_entity_name of this PiiDetectionDetailsFlaggedEntity.

        Custom entity name is the name of the custom-defined entity that was detected for this substring, if applicable.  # noqa: E501

        :param custom_entity_name: The custom_entity_name of this PiiDetectionDetailsFlaggedEntity.  # noqa: E501
        :type: str
        """

        self._custom_entity_name = custom_entity_name

    @property
    def flagged_substring(self):
        """Gets the flagged_substring of this PiiDetectionDetailsFlaggedEntity.  # noqa: E501


        :return: The flagged_substring of this PiiDetectionDetailsFlaggedEntity.  # noqa: E501
        :rtype: GenerativefirewallFlaggedSubstring
        """
        return self._flagged_substring

    @flagged_substring.setter
    def flagged_substring(self, flagged_substring):
        """Sets the flagged_substring of this PiiDetectionDetailsFlaggedEntity.


        :param flagged_substring: The flagged_substring of this PiiDetectionDetailsFlaggedEntity.  # noqa: E501
        :type: GenerativefirewallFlaggedSubstring
        """

        self._flagged_substring = flagged_substring

    @property
    def confidence_score(self):
        """Gets the confidence_score of this PiiDetectionDetailsFlaggedEntity.  # noqa: E501

        Confidence score is a metric of how confident (on a scale of 0-1) the rule is about this entity being flagged.  # noqa: E501

        :return: The confidence_score of this PiiDetectionDetailsFlaggedEntity.  # noqa: E501
        :rtype: float
        """
        return self._confidence_score

    @confidence_score.setter
    def confidence_score(self, confidence_score):
        """Sets the confidence_score of this PiiDetectionDetailsFlaggedEntity.

        Confidence score is a metric of how confident (on a scale of 0-1) the rule is about this entity being flagged.  # noqa: E501

        :param confidence_score: The confidence_score of this PiiDetectionDetailsFlaggedEntity.  # noqa: E501
        :type: float
        """

        self._confidence_score = confidence_score

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(PiiDetectionDetailsFlaggedEntity, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PiiDetectionDetailsFlaggedEntity):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Robust Intelligence REST API

    API methods for Robust Intelligence. Users must authenticate using the `rime-api-key` header.  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: dev@robustintelligence.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class CustomMetricCustomMetricMetadata(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'short_description': 'str',
        'starter_description': 'str',
        'why_it_matters_description': 'str',
        'configuration_description': 'str',
        'example_description': 'str'
    }

    attribute_map = {
        'short_description': 'shortDescription',
        'starter_description': 'starterDescription',
        'why_it_matters_description': 'whyItMattersDescription',
        'configuration_description': 'configurationDescription',
        'example_description': 'exampleDescription'
    }

    def __init__(self, short_description=None, starter_description=None, why_it_matters_description=None, configuration_description=None, example_description=None):  # noqa: E501
        """CustomMetricCustomMetricMetadata - a model defined in Swagger"""  # noqa: E501
        self._short_description = None
        self._starter_description = None
        self._why_it_matters_description = None
        self._configuration_description = None
        self._example_description = None
        self.discriminator = None
        if short_description is not None:
            self.short_description = short_description
        if starter_description is not None:
            self.starter_description = starter_description
        if why_it_matters_description is not None:
            self.why_it_matters_description = why_it_matters_description
        if configuration_description is not None:
            self.configuration_description = configuration_description
        if example_description is not None:
            self.example_description = example_description

    @property
    def short_description(self):
        """Gets the short_description of this CustomMetricCustomMetricMetadata.  # noqa: E501

        Short description.  # noqa: E501

        :return: The short_description of this CustomMetricCustomMetricMetadata.  # noqa: E501
        :rtype: str
        """
        return self._short_description

    @short_description.setter
    def short_description(self, short_description):
        """Sets the short_description of this CustomMetricCustomMetricMetadata.

        Short description.  # noqa: E501

        :param short_description: The short_description of this CustomMetricCustomMetricMetadata.  # noqa: E501
        :type: str
        """

        self._short_description = short_description

    @property
    def starter_description(self):
        """Gets the starter_description of this CustomMetricCustomMetricMetadata.  # noqa: E501

        Starter description.  # noqa: E501

        :return: The starter_description of this CustomMetricCustomMetricMetadata.  # noqa: E501
        :rtype: str
        """
        return self._starter_description

    @starter_description.setter
    def starter_description(self, starter_description):
        """Sets the starter_description of this CustomMetricCustomMetricMetadata.

        Starter description.  # noqa: E501

        :param starter_description: The starter_description of this CustomMetricCustomMetricMetadata.  # noqa: E501
        :type: str
        """

        self._starter_description = starter_description

    @property
    def why_it_matters_description(self):
        """Gets the why_it_matters_description of this CustomMetricCustomMetricMetadata.  # noqa: E501

        Why it matters description.  # noqa: E501

        :return: The why_it_matters_description of this CustomMetricCustomMetricMetadata.  # noqa: E501
        :rtype: str
        """
        return self._why_it_matters_description

    @why_it_matters_description.setter
    def why_it_matters_description(self, why_it_matters_description):
        """Sets the why_it_matters_description of this CustomMetricCustomMetricMetadata.

        Why it matters description.  # noqa: E501

        :param why_it_matters_description: The why_it_matters_description of this CustomMetricCustomMetricMetadata.  # noqa: E501
        :type: str
        """

        self._why_it_matters_description = why_it_matters_description

    @property
    def configuration_description(self):
        """Gets the configuration_description of this CustomMetricCustomMetricMetadata.  # noqa: E501

        Configuration description.  # noqa: E501

        :return: The configuration_description of this CustomMetricCustomMetricMetadata.  # noqa: E501
        :rtype: str
        """
        return self._configuration_description

    @configuration_description.setter
    def configuration_description(self, configuration_description):
        """Sets the configuration_description of this CustomMetricCustomMetricMetadata.

        Configuration description.  # noqa: E501

        :param configuration_description: The configuration_description of this CustomMetricCustomMetricMetadata.  # noqa: E501
        :type: str
        """

        self._configuration_description = configuration_description

    @property
    def example_description(self):
        """Gets the example_description of this CustomMetricCustomMetricMetadata.  # noqa: E501

        Example description.  # noqa: E501

        :return: The example_description of this CustomMetricCustomMetricMetadata.  # noqa: E501
        :rtype: str
        """
        return self._example_description

    @example_description.setter
    def example_description(self, example_description):
        """Sets the example_description of this CustomMetricCustomMetricMetadata.

        Example description.  # noqa: E501

        :param example_description: The example_description of this CustomMetricCustomMetricMetadata.  # noqa: E501
        :type: str
        """

        self._example_description = example_description

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(CustomMetricCustomMetricMetadata, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CustomMetricCustomMetricMetadata):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Robust Intelligence REST API

    API methods for Robust Intelligence. Users must authenticate using the `rime-api-key` header.  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: dev@robustintelligence.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class RimeCreateAPITokenRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'name': 'str',
        'workspace_id': 'RimeUUID',
        'token_type': 'RimeTokenType',
        'agent_id': 'RimeUUID',
        'expiry_days': 'int'
    }

    attribute_map = {
        'name': 'name',
        'workspace_id': 'workspaceId',
        'token_type': 'tokenType',
        'agent_id': 'agentId',
        'expiry_days': 'expiryDays'
    }

    def __init__(self, name=None, workspace_id=None, token_type=None, agent_id=None, expiry_days=None):  # noqa: E501
        """RimeCreateAPITokenRequest - a model defined in Swagger"""  # noqa: E501
        self._name = None
        self._workspace_id = None
        self._token_type = None
        self._agent_id = None
        self._expiry_days = None
        self.discriminator = None
        self.name = name
        if workspace_id is not None:
            self.workspace_id = workspace_id
        if token_type is not None:
            self.token_type = token_type
        if agent_id is not None:
            self.agent_id = agent_id
        if expiry_days is not None:
            self.expiry_days = expiry_days

    @property
    def name(self):
        """Gets the name of this RimeCreateAPITokenRequest.  # noqa: E501

        Name of the API token.  # noqa: E501

        :return: The name of this RimeCreateAPITokenRequest.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this RimeCreateAPITokenRequest.

        Name of the API token.  # noqa: E501

        :param name: The name of this RimeCreateAPITokenRequest.  # noqa: E501
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def workspace_id(self):
        """Gets the workspace_id of this RimeCreateAPITokenRequest.  # noqa: E501


        :return: The workspace_id of this RimeCreateAPITokenRequest.  # noqa: E501
        :rtype: RimeUUID
        """
        return self._workspace_id

    @workspace_id.setter
    def workspace_id(self, workspace_id):
        """Sets the workspace_id of this RimeCreateAPITokenRequest.


        :param workspace_id: The workspace_id of this RimeCreateAPITokenRequest.  # noqa: E501
        :type: RimeUUID
        """

        self._workspace_id = workspace_id

    @property
    def token_type(self):
        """Gets the token_type of this RimeCreateAPITokenRequest.  # noqa: E501


        :return: The token_type of this RimeCreateAPITokenRequest.  # noqa: E501
        :rtype: RimeTokenType
        """
        return self._token_type

    @token_type.setter
    def token_type(self, token_type):
        """Sets the token_type of this RimeCreateAPITokenRequest.


        :param token_type: The token_type of this RimeCreateAPITokenRequest.  # noqa: E501
        :type: RimeTokenType
        """

        self._token_type = token_type

    @property
    def agent_id(self):
        """Gets the agent_id of this RimeCreateAPITokenRequest.  # noqa: E501


        :return: The agent_id of this RimeCreateAPITokenRequest.  # noqa: E501
        :rtype: RimeUUID
        """
        return self._agent_id

    @agent_id.setter
    def agent_id(self, agent_id):
        """Sets the agent_id of this RimeCreateAPITokenRequest.


        :param agent_id: The agent_id of this RimeCreateAPITokenRequest.  # noqa: E501
        :type: RimeUUID
        """

        self._agent_id = agent_id

    @property
    def expiry_days(self):
        """Gets the expiry_days of this RimeCreateAPITokenRequest.  # noqa: E501


        :return: The expiry_days of this RimeCreateAPITokenRequest.  # noqa: E501
        :rtype: int
        """
        return self._expiry_days

    @expiry_days.setter
    def expiry_days(self, expiry_days):
        """Sets the expiry_days of this RimeCreateAPITokenRequest.


        :param expiry_days: The expiry_days of this RimeCreateAPITokenRequest.  # noqa: E501
        :type: int
        """

        self._expiry_days = expiry_days

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(RimeCreateAPITokenRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RimeCreateAPITokenRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



"""Library defining the interface to a Monitor."""

from typing import Any, Dict, Iterator, Optional

from rime_sdk.detection_event import DetectionEvent
from rime_sdk.internal.rest_error_handler import RESTErrorHandler
from rime_sdk.swagger.swagger_client import ApiClient, DetectionApi
from rime_sdk.swagger.swagger_client.api.monitor_service_api import MonitorServiceApi
from rime_sdk.swagger.swagger_client.models.detection_event_type import (
    DetectionEventType,
)
from rime_sdk.swagger.swagger_client.models.monitor_monitor import MonitorMonitor
from rime_sdk.swagger.swagger_client.models.rime_order import RimeOrder


class Monitor:
    """An interface to a Monitor object.

    Monitors track important model events over time including metric degradations or
    attacks on your model.
    """

    def __init__(
        self,
        api_client: ApiClient,
        monitor_id: str,
        firewall_id: str,
        project_id: str,
    ) -> None:
        """Initialize a new Monitor object.

        Args:
            api_client: ApiClient
                The client used to query for the up-to-date status of the Monitor.
            monitor_id: str
                The unique ID for the Monitor object.
            firewall_id: str
                The unique ID for the parent Firewall of the Monitor.
            project_id: str
                The unique ID for the parent Project of the Monitor.
        """
        self._api_client = api_client
        self._monitor_id = monitor_id
        self._firewall_id = firewall_id
        self._project_id = project_id

    def __repr__(self) -> str:
        """Return a string representation of the object."""
        return f"Monitor({self._monitor_id})"

    def update(self, notify: Optional[bool] = None) -> None:
        """Update the settings for the given Monitor in the backend.

        Args:
            notify: Optional[bool]
                A Boolean that specifies whether to enable Monitoring notifications
                for a given monitor. When Monitoring notifications are turned on for
                the same Project and the monitor finds a Detection Event, the system
                sends an alert.
        """
        api = MonitorServiceApi(self._api_client)
        monitor = MonitorMonitor(id=self._monitor_id)
        field_mask_list = []
        if notify is not None:
            field_mask_list.append("notify")
            monitor.notify = notify
        if len(field_mask_list) == 0:
            raise ValueError(
                "Please provide at least one keyword parameter to `update_monitor`."
            )
        body = {"monitor": monitor, "mask": ",".join(field_mask_list)}
        with RESTErrorHandler():
            api.monitor_service_update_monitor(body, self._monitor_id)

    def list_detected_events(self) -> Iterator[DetectionEvent]:
        """List detected Events for the given Monitor.

        For each continuous testing bin upload, RIME compares the
        metric value to the Monitor's thresholds and creates detection events
        when a degradation is detected.
        For a subset of Monitors, we perform Root Cause Analysis to explain
        the detailed cause of the Event.

        Returns:
            Iterator[DetectionEvent]:
                A generator of dictionary representations of Detection Events.
                They are sorted in reverse chronological order by the time at which
                the event occurred.

        Example:
            .. code-block:: python

                # List all default Monitors on the Firewall
                monitors = firewall.list_monitors(monitor_types=["Default"])
                # For each Monitor, list all detected Events.
                all_events = [monitor.list_detected_events() for monitor in monitors]
        """
        api = DetectionApi(self._api_client)
        next_page_token = ""
        has_more = True
        while has_more:
            kwargs: Dict[str, Any] = {}
            if len(next_page_token) > 0:
                kwargs["page_token"] = next_page_token
            else:
                # Return the events in reverse chronological order.
                # Also, only return CT events for the given monitor.
                kwargs["first_page_req_sort_sort_order"] = RimeOrder.DESCENDING
                kwargs["first_page_req_sort_sort_by"] = "event_time_range.end_time"
                kwargs["first_page_req_event_object_id"] = self._monitor_id
                kwargs["first_page_req_event_types"] = [
                    DetectionEventType.METRIC_DEGRADATION,
                    DetectionEventType.SECURITY,
                ]
            with RESTErrorHandler():
                res = api.detection_list_detection_events(
                    project_id_uuid=self._project_id, **kwargs
                )
            for detection_event in res.events:
                yield DetectionEvent(self._api_client, detection_event.to_dict())
            next_page_token = res.next_page_token
            has_more = res.has_more



"""Library providing a module for file services."""
from datetime import datetime, timezone
from pathlib import Path
from typing import Iterator, List, Optional

import requests
from requests.adapters import HTTPAdapter
from tqdm import tqdm
from tqdm.utils import CallbackIOWrapper

from rime_sdk.swagger.swagger_client import ApiClient, FileUploadApi
from rime_sdk.swagger.swagger_client.models.rime_get_dataset_file_upload_url_request import (
    RimeGetDatasetFileUploadURLRequest,
)
from rime_sdk.swagger.swagger_client.models.rime_get_model_directory_upload_urls_request import (
    RimeGetModelDirectoryUploadURLsRequest,
)


def _now_str() -> str:
    """Generate a date string for the current time."""
    return datetime.now(timezone.utc).strftime("%Y-%m-%dT%H:%M:%S%z")


def _is_hidden(path: Path, dir_path: Path) -> bool:
    return any(
        part for part in path.relative_to(dir_path).parts if part.startswith(".")
    )


def _get_files_to_upload(dir_path: Path, upload_hidden: bool) -> Iterator[Path]:
    paths: Iterator[Path] = dir_path.rglob("*")
    if not upload_hidden:
        paths = (path for path in paths if not _is_hidden(path, dir_path))
    return paths


class FileUploadMixin:
    """Mixin class with basic file upload utilities."""

    def _upload_object(self, file_path: Path, upload_url: str) -> None:
        """Upload the `file_path` to the location at `upload_url` via a PUT request."""
        file_size = file_path.stat().st_size
        with open(file_path, "rb") as f, self._get_requests_session() as session:
            with tqdm(
                total=file_size,
                unit="B",
                unit_scale=True,
                unit_divisor=1024,
                desc=f"Uploading {file_path}",
            ) as t:
                if file_size == 0:
                    # If the file is 0 bytes, using the TQDM io wrapper does not
                    # work, so we simply write an empty file directly.
                    http_response = session.put(url=upload_url, data="")
                    t.close()
                else:
                    wrapped_file = CallbackIOWrapper(t.update, f, "read")
                    http_response = session.put(url=upload_url, data=wrapped_file)
                if http_response.status_code != requests.codes.ok:
                    raise ValueError(
                        f"upload of '{file_path}' failed with "
                        + f"{http_response.status_code}: {http_response.reason}"
                    )

    @staticmethod
    def _get_requests_session() -> requests.Session:
        """Create request session for submitting HTTPS requests with retries."""
        session = requests.Session()
        adapter = HTTPAdapter(max_retries=5)
        session.mount("https://", adapter)
        return session

    @staticmethod
    def _impose_size_constraint(size: int, upload_limit: int) -> None:
        if (upload_limit != 0) and (size > upload_limit):
            raise ValueError(
                "Input is too large to be uploaded. Maximum size permitted "
                + f"is {upload_limit / (10 ** 6)}MB. "
                + f"Input size given is {size / (10 ** 6)}MB"
            )

    def _upload_string(self, file_contents: str, upload_url: str) -> None:
        """Upload `file_contents` to the location at `upload_url` via a PUT request."""
        with self._get_requests_session() as session:
            http_response = session.put(url=upload_url, data=file_contents)
            if http_response.status_code != requests.codes.ok:
                raise ValueError(
                    "upload of raw string file failed with "
                    + f"{http_response.status_code}: {http_response.reason}"
                )

    @staticmethod
    def _validate_file_path(file_path: Path) -> None:
        """Validate that the local file path is valid."""
        if not file_path.exists():
            raise FileNotFoundError(f"path '{file_path}' does not exist")
        if not file_path.is_file():
            raise OSError(f"path '{file_path}' is not a file")


class FileUploadModule(FileUploadMixin):
    """A module that implements file uploading using a FileUploadStub."""

    def __init__(self, api_client: ApiClient):
        """Create a FileUploadModule for the `file_upload_client`."""
        self._api_client = api_client
        self._file_upload_client = FileUploadApi(self._api_client)

    def upload_dataset_file(
        self,
        file_path: Path,
        upload_path: Optional[str] = None,
    ) -> str:
        """Upload dataset file ``file_path`` to RIME's blobstore via a FileUploadStub.

        The uploaded file is placed within the blobstore using its file name.

        Args:
            file_path: Path
                Path to the file to be uploaded to RIME's blob store.
            upload_path: Optional[str] = None
                Name of the directory in the blob store file system. If omitted,
                a unique random string will be the directory.

        Returns:
            str:
                A reference to the uploaded file's location in the blob store. This
                reference can be used to refer to that object when writing RIME configs.

        Raises:
            FileNotFoundError
                When the path ``file_path`` does not exist.
            OSError
                When ``file_path`` is not a file.
            ValueError
                When there was an error in obtaining a blobstore location from the
                RIME backend or in uploading ``file_path`` to RIME's blob store.
        """
        self._validate_file_path(file_path)

        file_size = file_path.stat().st_size
        file_name = file_path.name

        req = RimeGetDatasetFileUploadURLRequest(
            file_name=file_name,
            upload_path=upload_path,
        )
        resp = self._file_upload_client.file_upload_get_dataset_file_upload_url2(
            body=req
        )
        self._impose_size_constraint(file_size, int(resp.upload_limit))
        self._upload_object(file_path, resp.upload_url)
        self._upload_string(f"Upload complete: {_now_str()}", resp.done_file_upload_url)
        return resp.destination_url

    def upload_model_directory(
        self,
        dir_path: Path,
        upload_hidden: bool = False,
        upload_path: Optional[str] = None,
    ) -> str:
        """Upload model directory ``dir_path`` to RIME's blobstore via a FileUploadStub.

        All files contained within ``dir_path`` and its subdirectories are uploaded
        according to their relative paths within ``dir_path``.  However, if
        upload_hidden is False, all hidden files and subdirectories beginning with
        a '.' are not uploaded.

        Args:
            dir_path: Path
                Path to the directory to be uploaded to RIME's blob store.
            upload_hidden: bool = False
                Whether or not to upload hidden files or subdirectories
                (ie. those beginning with a '.').
            upload_path: Optional[str] = None
                Name of the directory in the blob store file system. If omitted,
                a unique random string will be the directory.

        Returns:
            str:
                A reference to the uploaded directory's location in the blob store. This
                reference can be used to refer to that object when writing RIME configs.

        Raises:
            FileNotFoundError
                When the directory ``dir_path`` does not exist.
            OSError
                When ``dir_path`` is not a directory or contains no files.
            ValueError
                When there was an error in obtaining a blobstore location from the
                RIME backend or in uploading ``dir_path`` to RIME's blob store.
        """
        if not dir_path.exists():
            raise FileNotFoundError(f"path '{dir_path}' does not exist")
        if not dir_path.is_dir():
            raise OSError(f"path '{dir_path}' is not a directory")
        sub_paths = _get_files_to_upload(dir_path, upload_hidden)
        rel_paths: List[str] = []
        total_size: int = 0
        for file_path in sub_paths:
            if file_path.is_file():
                total_size += file_path.stat().st_size
                rel_paths.append(str(file_path.relative_to(dir_path)))
        if len(rel_paths) == 0:
            raise OSError(f"directory '{dir_path}' is empty")
        req = RimeGetModelDirectoryUploadURLsRequest(
            directory_name=dir_path.name,
            relative_file_paths=rel_paths,
            upload_path=upload_path,
        )
        resp = self._file_upload_client.file_upload_get_model_directory_upload_urls2(
            body=req
        )
        self._impose_size_constraint(total_size, int(resp.upload_limit))
        for rel_path in resp.upload_path_map:
            file_path = dir_path / rel_path
            self._upload_object(file_path, resp.upload_path_map[rel_path])
        self._upload_string(f"Upload complete: {_now_str()}", resp.done_file_upload_url)
        return resp.destination_url

    def list_uploaded_files_urls(self) -> Iterator[str]:
        """Return an iterator of file paths that have been uploaded."""
        resp = self._file_upload_client.file_upload_list_uploaded_file_urls()
        return resp.file_urls

    def delete_uploaded_file_url(self, upload_url: str) -> None:
        """Delete file at `upload_url`.

        Args:
            upload_url: str
                Url to the file to be deleted in the RIME blob store.
        """
        self._file_upload_client.file_upload_delete_uploaded_file_url(upload_url)


_FIREWALL_UPLOAD_SIZE_LIMIT = int(1e7)  # 10 MB



# coding: utf-8

"""
    Robust Intelligence REST API

    API methods for Robust Intelligence. Users must authenticate using the `rime-api-key` header.  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: dev@robustintelligence.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class TestrunresultTestCaseDisplay(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'table_info': 'str',
        'details': 'str',
        'details_layout': 'list[str]'
    }

    attribute_map = {
        'table_info': 'tableInfo',
        'details': 'details',
        'details_layout': 'detailsLayout'
    }

    def __init__(self, table_info=None, details=None, details_layout=None):  # noqa: E501
        """TestrunresultTestCaseDisplay - a model defined in Swagger"""  # noqa: E501
        self._table_info = None
        self._details = None
        self._details_layout = None
        self.discriminator = None
        if table_info is not None:
            self.table_info = table_info
        if details is not None:
            self.details = details
        if details_layout is not None:
            self.details_layout = details_layout

    @property
    def table_info(self):
        """Gets the table_info of this TestrunresultTestCaseDisplay.  # noqa: E501

        Table info contains information for displaying the test case in a table in the FE.  # noqa: E501

        :return: The table_info of this TestrunresultTestCaseDisplay.  # noqa: E501
        :rtype: str
        """
        return self._table_info

    @table_info.setter
    def table_info(self, table_info):
        """Sets the table_info of this TestrunresultTestCaseDisplay.

        Table info contains information for displaying the test case in a table in the FE.  # noqa: E501

        :param table_info: The table_info of this TestrunresultTestCaseDisplay.  # noqa: E501
        :type: str
        """

        self._table_info = table_info

    @property
    def details(self):
        """Gets the details of this TestrunresultTestCaseDisplay.  # noqa: E501

        Details includes ML-specified details for the test case. This can include graphs, HTML, etc.  # noqa: E501

        :return: The details of this TestrunresultTestCaseDisplay.  # noqa: E501
        :rtype: str
        """
        return self._details

    @details.setter
    def details(self, details):
        """Sets the details of this TestrunresultTestCaseDisplay.

        Details includes ML-specified details for the test case. This can include graphs, HTML, etc.  # noqa: E501

        :param details: The details of this TestrunresultTestCaseDisplay.  # noqa: E501
        :type: str
        """

        self._details = details

    @property
    def details_layout(self):
        """Gets the details_layout of this TestrunresultTestCaseDisplay.  # noqa: E501


        :return: The details_layout of this TestrunresultTestCaseDisplay.  # noqa: E501
        :rtype: list[str]
        """
        return self._details_layout

    @details_layout.setter
    def details_layout(self, details_layout):
        """Sets the details_layout of this TestrunresultTestCaseDisplay.


        :param details_layout: The details_layout of this TestrunresultTestCaseDisplay.  # noqa: E501
        :type: list[str]
        """

        self._details_layout = details_layout

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(TestrunresultTestCaseDisplay, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TestrunresultTestCaseDisplay):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



"""Library defining the interface to a Test Batch object."""
import pandas as pd

from rime_sdk.internal.rest_error_handler import RESTErrorHandler
from rime_sdk.internal.swagger_parser import (
    parse_test_batch_result,
    parse_test_case_result,
)
from rime_sdk.internal.test_helpers import get_batch_result_response
from rime_sdk.swagger import swagger_client
from rime_sdk.swagger.swagger_client import ApiClient


class TestBatch:
    """An interface for a Test Batch object in a RIME Test Run."""

    def __init__(self, api_client: ApiClient, test_run_id: str, test_type: str) -> None:
        """Contains information about a ``TestBatch`` object.

        Args:
            api_client: ApiClient
                The client used to query about the status of the job.
            test_run_id: str
                The ID for the Test Run this Test Batch belong to.
            test_type: str
                The test type of this Test Batch e.g. unseen_categorical.
        """
        self._api_client = api_client
        self._test_run_id = test_run_id
        self._test_type = test_type

    def __repr__(self) -> str:
        """Return a string representation of the Test Batch."""
        return (
            f"TestBatch(test_run_id={self._test_run_id}, test_type={self._test_type})"
        )

    @property
    def test_run_id(self) -> str:
        """Return the Test Run ID of the Test Batch."""
        return self._test_run_id

    @property
    def test_type(self) -> str:
        """Return the type of the Test Batch."""
        return self._test_type

    def summary(self, show_batch_metrics: bool = False) -> pd.Series:
        """Return the Test Batch summary as a Pandas Series.

        The summary contains high level information about a Test Batch.
        For example, the name of the Test Batch, the category, and the
        severity of the Test Batch as a whole.

        Returns:
            pd.Series:
                A Pandas Series with the following columns (and optional additional
                columns for batch-level metrics):

                    1. test_run_id
                    2. test_type
                    3. test_name
                    4. category
                    5. duration_in_millis
                    6. severity
                    7. failing_features
                    8. description
                    9. summary_counts.total
                    10. summary_counts.pass
                    11. summary_counts.fail
                    12. summary_counts.warning
                    13. summary_counts.skip
        """
        res = get_batch_result_response(
            self._test_run_id,
            self._test_type,
            self._api_client,
        )
        return parse_test_batch_result(
            res.test_batch, unpack_metrics=show_batch_metrics
        )

    def get_test_cases_df(self) -> pd.DataFrame:
        """Return all Test Cases in the Test Batch as a Pandas DataFrame.

        Different tests will have different columns/information.
        For example, some tests may have a column representing
        the number of failing rows.

        Returns:
            pd.DataFrame:
                A Pandas Dataframe where each row represents a Test Case.

        Example:
            .. code-block:: python

                # Wait until the job has finished, since this method only works on
                # SUCCEEDED jobs.
                job.get_status(verbose=True, wait_until_finish=True)
                # Get the Test Run result.
                test_run = job.get_test_run()
                # Get the "subset accuracy" Test Batch from this Test Run.
                test_batch = test_run.get_test_batch("subset_performance:subset_recall")
                # Return the Test Cases from this Test Batch in a dataframe ``df``.
                df = test_batch.get_test_cases_df()
        """
        # don't forget to exhaust pages if necessary
        api = swagger_client.ResultsReaderApi(self._api_client)
        all_test_cases = []
        # Iterate through the pages of Test Cases and break at the last page.
        page_token = ""
        while True:
            with RESTErrorHandler():
                if page_token == "":
                    res = api.results_reader_list_test_cases(
                        list_test_cases_query_test_run_id=self._test_run_id,
                        list_test_cases_query_test_types=[self._test_type],
                        page_size=20,
                    )
                else:
                    res = api.results_reader_list_test_cases(
                        page_token=page_token,
                        page_size=20,
                    )
            if res.test_cases:
                tc_dicts = [
                    parse_test_case_result(tc, unpack_metrics=True)
                    for tc in res.test_cases
                ]
                # Concatenate the list of Test Case dictionaries.
                all_test_cases += tc_dicts
            # Advance to the next page of Test Cases.
            page_token = res.next_page_token

            # we've reached the last page of Test Cases.
            if not res.has_more:
                break

        return pd.DataFrame(all_test_cases)



# coding: utf-8

"""
    Robust Intelligence REST API

    API methods for Robust Intelligence. Users must authenticate using the `rime-api-key` header.  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: dev@robustintelligence.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from rime_sdk.swagger.swagger_client.api_client import ApiClient


class FirewallInstanceManagerApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def firewall_instance_manager_create_firewall_instance(self, body, **kwargs):  # noqa: E501
        """CreateFirewallInstance  # noqa: E501

        This creates a new Firewall Instance with the desired user configuration. It will take time for the new instance to become available; use the `GetFirewallInstance` API to track the status of the deployment.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.firewall_instance_manager_create_firewall_instance(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param GenerativefirewallCreateFirewallInstanceRequest body: (required)
        :return: GenerativefirewallCreateFirewallInstanceResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.firewall_instance_manager_create_firewall_instance_with_http_info(body, **kwargs)  # noqa: E501
        else:
            (data) = self.firewall_instance_manager_create_firewall_instance_with_http_info(body, **kwargs)  # noqa: E501
            return data

    def firewall_instance_manager_create_firewall_instance_with_http_info(self, body, **kwargs):  # noqa: E501
        """CreateFirewallInstance  # noqa: E501

        This creates a new Firewall Instance with the desired user configuration. It will take time for the new instance to become available; use the `GetFirewallInstance` API to track the status of the deployment.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.firewall_instance_manager_create_firewall_instance_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param GenerativefirewallCreateFirewallInstanceRequest body: (required)
        :return: GenerativefirewallCreateFirewallInstanceResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method firewall_instance_manager_create_firewall_instance" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `firewall_instance_manager_create_firewall_instance`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Firewall-Api-Key', 'X-Firewall-Auth-Token', 'rime-api-key']  # noqa: E501

        return self.api_client.call_api(
            '/v1-beta/firewall-instance', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='GenerativefirewallCreateFirewallInstanceResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def firewall_instance_manager_delete_firewall_instance(self, firewall_instance_id_uuid, **kwargs):  # noqa: E501
        """DeleteFirewallInstance  # noqa: E501

        This hard-deletes a Firewall Instance from the cluster. Be careful with this API because it will interrupt in-flight validation.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.firewall_instance_manager_delete_firewall_instance(firewall_instance_id_uuid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str firewall_instance_id_uuid: Unique object ID. (required)
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.firewall_instance_manager_delete_firewall_instance_with_http_info(firewall_instance_id_uuid, **kwargs)  # noqa: E501
        else:
            (data) = self.firewall_instance_manager_delete_firewall_instance_with_http_info(firewall_instance_id_uuid, **kwargs)  # noqa: E501
            return data

    def firewall_instance_manager_delete_firewall_instance_with_http_info(self, firewall_instance_id_uuid, **kwargs):  # noqa: E501
        """DeleteFirewallInstance  # noqa: E501

        This hard-deletes a Firewall Instance from the cluster. Be careful with this API because it will interrupt in-flight validation.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.firewall_instance_manager_delete_firewall_instance_with_http_info(firewall_instance_id_uuid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str firewall_instance_id_uuid: Unique object ID. (required)
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['firewall_instance_id_uuid']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method firewall_instance_manager_delete_firewall_instance" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'firewall_instance_id_uuid' is set
        if ('firewall_instance_id_uuid' not in params or
                params['firewall_instance_id_uuid'] is None):
            raise ValueError("Missing the required parameter `firewall_instance_id_uuid` when calling `firewall_instance_manager_delete_firewall_instance`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'firewall_instance_id_uuid' in params:
            path_params['firewallInstanceId.uuid'] = params['firewall_instance_id_uuid']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Firewall-Api-Key', 'X-Firewall-Auth-Token', 'rime-api-key']  # noqa: E501

        return self.api_client.call_api(
            '/v1-beta/firewall-instance/{firewallInstanceId.uuid}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='object',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def firewall_instance_manager_get_firewall_instance(self, firewall_instance_id_uuid, **kwargs):  # noqa: E501
        """GetFirewallInstance  # noqa: E501

        This retrieves information about a single Firewall Instance.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.firewall_instance_manager_get_firewall_instance(firewall_instance_id_uuid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str firewall_instance_id_uuid: Unique object ID. (required)
        :return: GenerativefirewallGetFirewallInstanceResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.firewall_instance_manager_get_firewall_instance_with_http_info(firewall_instance_id_uuid, **kwargs)  # noqa: E501
        else:
            (data) = self.firewall_instance_manager_get_firewall_instance_with_http_info(firewall_instance_id_uuid, **kwargs)  # noqa: E501
            return data

    def firewall_instance_manager_get_firewall_instance_with_http_info(self, firewall_instance_id_uuid, **kwargs):  # noqa: E501
        """GetFirewallInstance  # noqa: E501

        This retrieves information about a single Firewall Instance.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.firewall_instance_manager_get_firewall_instance_with_http_info(firewall_instance_id_uuid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str firewall_instance_id_uuid: Unique object ID. (required)
        :return: GenerativefirewallGetFirewallInstanceResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['firewall_instance_id_uuid']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method firewall_instance_manager_get_firewall_instance" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'firewall_instance_id_uuid' is set
        if ('firewall_instance_id_uuid' not in params or
                params['firewall_instance_id_uuid'] is None):
            raise ValueError("Missing the required parameter `firewall_instance_id_uuid` when calling `firewall_instance_manager_get_firewall_instance`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'firewall_instance_id_uuid' in params:
            path_params['firewallInstanceId.uuid'] = params['firewall_instance_id_uuid']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Firewall-Api-Key', 'X-Firewall-Auth-Token', 'rime-api-key']  # noqa: E501

        return self.api_client.call_api(
            '/v1-beta/firewall-instance/{firewallInstanceId.uuid}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='GenerativefirewallGetFirewallInstanceResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def firewall_instance_manager_list_firewall_instances(self, **kwargs):  # noqa: E501
        """ListFirewallInstances  # noqa: E501

        This lists the Firewall Instances on the cluster.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.firewall_instance_manager_list_firewall_instances(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: GenerativefirewallListFirewallInstancesResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.firewall_instance_manager_list_firewall_instances_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.firewall_instance_manager_list_firewall_instances_with_http_info(**kwargs)  # noqa: E501
            return data

    def firewall_instance_manager_list_firewall_instances_with_http_info(self, **kwargs):  # noqa: E501
        """ListFirewallInstances  # noqa: E501

        This lists the Firewall Instances on the cluster.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.firewall_instance_manager_list_firewall_instances_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: GenerativefirewallListFirewallInstancesResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method firewall_instance_manager_list_firewall_instances" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Firewall-Api-Key', 'X-Firewall-Auth-Token', 'rime-api-key']  # noqa: E501

        return self.api_client.call_api(
            '/v1-beta/firewall-instance', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='GenerativefirewallListFirewallInstancesResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def firewall_instance_manager_update_firewall_instance(self, body, firewall_instance_firewall_instance_id_uuid, **kwargs):  # noqa: E501
        """UpdateFirewallInstance  # noqa: E501

        Update an existing FirewallInstance. This redeploys the firewall instance. The status will be REDEPLOYING until the new version of the firewall instance reaches READY.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.firewall_instance_manager_update_firewall_instance(body, firewall_instance_firewall_instance_id_uuid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param FirewallinstanceFirewallInstanceFirewallInstanceIdUuidBody body: (required)
        :param str firewall_instance_firewall_instance_id_uuid: Unique object ID. (required)
        :param str mask:
        :return: GenerativefirewallUpdateFirewallInstanceResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.firewall_instance_manager_update_firewall_instance_with_http_info(body, firewall_instance_firewall_instance_id_uuid, **kwargs)  # noqa: E501
        else:
            (data) = self.firewall_instance_manager_update_firewall_instance_with_http_info(body, firewall_instance_firewall_instance_id_uuid, **kwargs)  # noqa: E501
            return data

    def firewall_instance_manager_update_firewall_instance_with_http_info(self, body, firewall_instance_firewall_instance_id_uuid, **kwargs):  # noqa: E501
        """UpdateFirewallInstance  # noqa: E501

        Update an existing FirewallInstance. This redeploys the firewall instance. The status will be REDEPLOYING until the new version of the firewall instance reaches READY.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.firewall_instance_manager_update_firewall_instance_with_http_info(body, firewall_instance_firewall_instance_id_uuid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param FirewallinstanceFirewallInstanceFirewallInstanceIdUuidBody body: (required)
        :param str firewall_instance_firewall_instance_id_uuid: Unique object ID. (required)
        :param str mask:
        :return: GenerativefirewallUpdateFirewallInstanceResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'firewall_instance_firewall_instance_id_uuid', 'mask']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method firewall_instance_manager_update_firewall_instance" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `firewall_instance_manager_update_firewall_instance`")  # noqa: E501
        # verify the required parameter 'firewall_instance_firewall_instance_id_uuid' is set
        if ('firewall_instance_firewall_instance_id_uuid' not in params or
                params['firewall_instance_firewall_instance_id_uuid'] is None):
            raise ValueError("Missing the required parameter `firewall_instance_firewall_instance_id_uuid` when calling `firewall_instance_manager_update_firewall_instance`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'firewall_instance_firewall_instance_id_uuid' in params:
            path_params['firewallInstance.firewallInstanceId.uuid'] = params['firewall_instance_firewall_instance_id_uuid']  # noqa: E501

        query_params = []
        if 'mask' in params:
            query_params.append(('mask', params['mask']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Firewall-Api-Key', 'X-Firewall-Auth-Token', 'rime-api-key']  # noqa: E501

        return self.api_client.call_api(
            '/v1-beta/firewall-instance/{firewallInstance.firewallInstanceId.uuid}', 'PATCH',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='GenerativefirewallUpdateFirewallInstanceResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Robust Intelligence REST API

    API methods for Robust Intelligence. Users must authenticate using the `rime-api-key` header.  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: dev@robustintelligence.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from rime_sdk.swagger.swagger_client.api_client import ApiClient


class DataCollectorApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def data_collector_get_datapoints(self, data_stream_id_uuid, **kwargs):  # noqa: E501
        """GetDatapoints  # noqa: E501

        GetDatapoints returns all datapoints from a time period.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.data_collector_get_datapoints(data_stream_id_uuid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str data_stream_id_uuid: Unique object ID. (required)
        :param datetime time_interval_start_time:
        :param datetime time_interval_end_time:
        :return: StreamResultOfRimeGetDatapointsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.data_collector_get_datapoints_with_http_info(data_stream_id_uuid, **kwargs)  # noqa: E501
        else:
            (data) = self.data_collector_get_datapoints_with_http_info(data_stream_id_uuid, **kwargs)  # noqa: E501
            return data

    def data_collector_get_datapoints_with_http_info(self, data_stream_id_uuid, **kwargs):  # noqa: E501
        """GetDatapoints  # noqa: E501

        GetDatapoints returns all datapoints from a time period.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.data_collector_get_datapoints_with_http_info(data_stream_id_uuid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str data_stream_id_uuid: Unique object ID. (required)
        :param datetime time_interval_start_time:
        :param datetime time_interval_end_time:
        :return: StreamResultOfRimeGetDatapointsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['data_stream_id_uuid', 'time_interval_start_time', 'time_interval_end_time']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method data_collector_get_datapoints" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'data_stream_id_uuid' is set
        if ('data_stream_id_uuid' not in params or
                params['data_stream_id_uuid'] is None):
            raise ValueError("Missing the required parameter `data_stream_id_uuid` when calling `data_collector_get_datapoints`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'data_stream_id_uuid' in params:
            path_params['dataStreamId.uuid'] = params['data_stream_id_uuid']  # noqa: E501

        query_params = []
        if 'time_interval_start_time' in params:
            query_params.append(('timeInterval.startTime', params['time_interval_start_time']))  # noqa: E501
        if 'time_interval_end_time' in params:
            query_params.append(('timeInterval.endTime', params['time_interval_end_time']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Firewall-Api-Key', 'X-Firewall-Auth-Token', 'rime-api-key']  # noqa: E501

        return self.api_client.call_api(
            '/v1-beta/data-collector/datapoints/{dataStreamId.uuid}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='StreamResultOfRimeGetDatapointsResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def data_collector_get_predictions(self, model_id_uuid, data_stream_id_uuid, **kwargs):  # noqa: E501
        """GetPredictions  # noqa: E501

        GetPredictions returns all predictions from a time period  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.data_collector_get_predictions(model_id_uuid, data_stream_id_uuid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str model_id_uuid: Unique object ID. (required)
        :param str data_stream_id_uuid: Unique object ID. (required)
        :param datetime time_interval_start_time:
        :param datetime time_interval_end_time:
        :return: StreamResultOfRimeGetPredictionsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.data_collector_get_predictions_with_http_info(model_id_uuid, data_stream_id_uuid, **kwargs)  # noqa: E501
        else:
            (data) = self.data_collector_get_predictions_with_http_info(model_id_uuid, data_stream_id_uuid, **kwargs)  # noqa: E501
            return data

    def data_collector_get_predictions_with_http_info(self, model_id_uuid, data_stream_id_uuid, **kwargs):  # noqa: E501
        """GetPredictions  # noqa: E501

        GetPredictions returns all predictions from a time period  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.data_collector_get_predictions_with_http_info(model_id_uuid, data_stream_id_uuid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str model_id_uuid: Unique object ID. (required)
        :param str data_stream_id_uuid: Unique object ID. (required)
        :param datetime time_interval_start_time:
        :param datetime time_interval_end_time:
        :return: StreamResultOfRimeGetPredictionsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['model_id_uuid', 'data_stream_id_uuid', 'time_interval_start_time', 'time_interval_end_time']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method data_collector_get_predictions" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'model_id_uuid' is set
        if ('model_id_uuid' not in params or
                params['model_id_uuid'] is None):
            raise ValueError("Missing the required parameter `model_id_uuid` when calling `data_collector_get_predictions`")  # noqa: E501
        # verify the required parameter 'data_stream_id_uuid' is set
        if ('data_stream_id_uuid' not in params or
                params['data_stream_id_uuid'] is None):
            raise ValueError("Missing the required parameter `data_stream_id_uuid` when calling `data_collector_get_predictions`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'model_id_uuid' in params:
            path_params['modelId.uuid'] = params['model_id_uuid']  # noqa: E501
        if 'data_stream_id_uuid' in params:
            path_params['dataStreamId.uuid'] = params['data_stream_id_uuid']  # noqa: E501

        query_params = []
        if 'time_interval_start_time' in params:
            query_params.append(('timeInterval.startTime', params['time_interval_start_time']))  # noqa: E501
        if 'time_interval_end_time' in params:
            query_params.append(('timeInterval.endTime', params['time_interval_end_time']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Firewall-Api-Key', 'X-Firewall-Auth-Token', 'rime-api-key']  # noqa: E501

        return self.api_client.call_api(
            '/v1-beta/data-collector/predictions/{modelId.uuid}/{dataStreamId.uuid}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='StreamResultOfRimeGetPredictionsResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def data_collector_register_data_stream(self, body, project_id_uuid, **kwargs):  # noqa: E501
        """RegisterDataStream  # noqa: E501

        Registers a new data stream. A data stream is a location where data points are stored. All data points that are in the same registered data set must be stored in the same data stream.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.data_collector_register_data_stream(body, project_id_uuid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param DatastreamProjectIdUuidBody body: (required)
        :param str project_id_uuid: Unique object ID. (required)
        :return: RimeRegisterDataStreamResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.data_collector_register_data_stream_with_http_info(body, project_id_uuid, **kwargs)  # noqa: E501
        else:
            (data) = self.data_collector_register_data_stream_with_http_info(body, project_id_uuid, **kwargs)  # noqa: E501
            return data

    def data_collector_register_data_stream_with_http_info(self, body, project_id_uuid, **kwargs):  # noqa: E501
        """RegisterDataStream  # noqa: E501

        Registers a new data stream. A data stream is a location where data points are stored. All data points that are in the same registered data set must be stored in the same data stream.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.data_collector_register_data_stream_with_http_info(body, project_id_uuid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param DatastreamProjectIdUuidBody body: (required)
        :param str project_id_uuid: Unique object ID. (required)
        :return: RimeRegisterDataStreamResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'project_id_uuid']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method data_collector_register_data_stream" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `data_collector_register_data_stream`")  # noqa: E501
        # verify the required parameter 'project_id_uuid' is set
        if ('project_id_uuid' not in params or
                params['project_id_uuid'] is None):
            raise ValueError("Missing the required parameter `project_id_uuid` when calling `data_collector_register_data_stream`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_id_uuid' in params:
            path_params['projectId.uuid'] = params['project_id_uuid']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Firewall-Api-Key', 'X-Firewall-Auth-Token', 'rime-api-key']  # noqa: E501

        return self.api_client.call_api(
            '/v1-beta/data-collector/datastream/{projectId.uuid}', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='RimeRegisterDataStreamResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def data_collector_store_datapoints(self, body, data_stream_id_uuid, **kwargs):  # noqa: E501
        """StoreDatapoints  # noqa: E501

        Store multiple new datapoints into a data stream.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.data_collector_store_datapoints(body, data_stream_id_uuid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param DataDataStreamIdUuidBody body: (required)
        :param str data_stream_id_uuid: Unique object ID. (required)
        :return: RimeStoreDatapointsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.data_collector_store_datapoints_with_http_info(body, data_stream_id_uuid, **kwargs)  # noqa: E501
        else:
            (data) = self.data_collector_store_datapoints_with_http_info(body, data_stream_id_uuid, **kwargs)  # noqa: E501
            return data

    def data_collector_store_datapoints_with_http_info(self, body, data_stream_id_uuid, **kwargs):  # noqa: E501
        """StoreDatapoints  # noqa: E501

        Store multiple new datapoints into a data stream.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.data_collector_store_datapoints_with_http_info(body, data_stream_id_uuid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param DataDataStreamIdUuidBody body: (required)
        :param str data_stream_id_uuid: Unique object ID. (required)
        :return: RimeStoreDatapointsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'data_stream_id_uuid']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method data_collector_store_datapoints" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `data_collector_store_datapoints`")  # noqa: E501
        # verify the required parameter 'data_stream_id_uuid' is set
        if ('data_stream_id_uuid' not in params or
                params['data_stream_id_uuid'] is None):
            raise ValueError("Missing the required parameter `data_stream_id_uuid` when calling `data_collector_store_datapoints`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'data_stream_id_uuid' in params:
            path_params['dataStreamId.uuid'] = params['data_stream_id_uuid']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Firewall-Api-Key', 'X-Firewall-Auth-Token', 'rime-api-key']  # noqa: E501

        return self.api_client.call_api(
            '/v1-beta/data-collector/data/{dataStreamId.uuid}', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='RimeStoreDatapointsResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def data_collector_store_predictions(self, body, model_id_uuid, **kwargs):  # noqa: E501
        """StorePredictions  # noqa: E501

        Store multiple new predictions.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.data_collector_store_predictions(body, model_id_uuid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param PredictionsModelIdUuidBody body: (required)
        :param str model_id_uuid: Unique object ID. (required)
        :return: RimeStorePredictionsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.data_collector_store_predictions_with_http_info(body, model_id_uuid, **kwargs)  # noqa: E501
        else:
            (data) = self.data_collector_store_predictions_with_http_info(body, model_id_uuid, **kwargs)  # noqa: E501
            return data

    def data_collector_store_predictions_with_http_info(self, body, model_id_uuid, **kwargs):  # noqa: E501
        """StorePredictions  # noqa: E501

        Store multiple new predictions.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.data_collector_store_predictions_with_http_info(body, model_id_uuid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param PredictionsModelIdUuidBody body: (required)
        :param str model_id_uuid: Unique object ID. (required)
        :return: RimeStorePredictionsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'model_id_uuid']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method data_collector_store_predictions" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `data_collector_store_predictions`")  # noqa: E501
        # verify the required parameter 'model_id_uuid' is set
        if ('model_id_uuid' not in params or
                params['model_id_uuid'] is None):
            raise ValueError("Missing the required parameter `model_id_uuid` when calling `data_collector_store_predictions`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'model_id_uuid' in params:
            path_params['modelId.uuid'] = params['model_id_uuid']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Firewall-Api-Key', 'X-Firewall-Auth-Token', 'rime-api-key']  # noqa: E501

        return self.api_client.call_api(
            '/v1-beta/data-collector/predictions/{modelId.uuid}', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='RimeStorePredictionsResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Robust Intelligence REST API

    API methods for Robust Intelligence. Users must authenticate using the `rime-api-key` header.  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: dev@robustintelligence.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class GenerativefirewallFlaggedSubstring(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'request_body_component': 'FlaggedSubstringRequestBodyComponent',
        'context_index': 'str',
        'substring_start_index': 'str',
        'substring_end_index': 'str'
    }

    attribute_map = {
        'request_body_component': 'requestBodyComponent',
        'context_index': 'contextIndex',
        'substring_start_index': 'substringStartIndex',
        'substring_end_index': 'substringEndIndex'
    }

    def __init__(self, request_body_component=None, context_index=None, substring_start_index=None, substring_end_index=None):  # noqa: E501
        """GenerativefirewallFlaggedSubstring - a model defined in Swagger"""  # noqa: E501
        self._request_body_component = None
        self._context_index = None
        self._substring_start_index = None
        self._substring_end_index = None
        self.discriminator = None
        if request_body_component is not None:
            self.request_body_component = request_body_component
        if context_index is not None:
            self.context_index = context_index
        if substring_start_index is not None:
            self.substring_start_index = substring_start_index
        if substring_end_index is not None:
            self.substring_end_index = substring_end_index

    @property
    def request_body_component(self):
        """Gets the request_body_component of this GenerativefirewallFlaggedSubstring.  # noqa: E501


        :return: The request_body_component of this GenerativefirewallFlaggedSubstring.  # noqa: E501
        :rtype: FlaggedSubstringRequestBodyComponent
        """
        return self._request_body_component

    @request_body_component.setter
    def request_body_component(self, request_body_component):
        """Sets the request_body_component of this GenerativefirewallFlaggedSubstring.


        :param request_body_component: The request_body_component of this GenerativefirewallFlaggedSubstring.  # noqa: E501
        :type: FlaggedSubstringRequestBodyComponent
        """

        self._request_body_component = request_body_component

    @property
    def context_index(self):
        """Gets the context_index of this GenerativefirewallFlaggedSubstring.  # noqa: E501

        Context index denotes which of the texts in the contexts provided in the validate request contains the substring.  # noqa: E501

        :return: The context_index of this GenerativefirewallFlaggedSubstring.  # noqa: E501
        :rtype: str
        """
        return self._context_index

    @context_index.setter
    def context_index(self, context_index):
        """Sets the context_index of this GenerativefirewallFlaggedSubstring.

        Context index denotes which of the texts in the contexts provided in the validate request contains the substring.  # noqa: E501

        :param context_index: The context_index of this GenerativefirewallFlaggedSubstring.  # noqa: E501
        :type: str
        """

        self._context_index = context_index

    @property
    def substring_start_index(self):
        """Gets the substring_start_index of this GenerativefirewallFlaggedSubstring.  # noqa: E501


        :return: The substring_start_index of this GenerativefirewallFlaggedSubstring.  # noqa: E501
        :rtype: str
        """
        return self._substring_start_index

    @substring_start_index.setter
    def substring_start_index(self, substring_start_index):
        """Sets the substring_start_index of this GenerativefirewallFlaggedSubstring.


        :param substring_start_index: The substring_start_index of this GenerativefirewallFlaggedSubstring.  # noqa: E501
        :type: str
        """

        self._substring_start_index = substring_start_index

    @property
    def substring_end_index(self):
        """Gets the substring_end_index of this GenerativefirewallFlaggedSubstring.  # noqa: E501


        :return: The substring_end_index of this GenerativefirewallFlaggedSubstring.  # noqa: E501
        :rtype: str
        """
        return self._substring_end_index

    @substring_end_index.setter
    def substring_end_index(self, substring_end_index):
        """Sets the substring_end_index of this GenerativefirewallFlaggedSubstring.


        :param substring_end_index: The substring_end_index of this GenerativefirewallFlaggedSubstring.  # noqa: E501
        :type: str
        """

        self._substring_end_index = substring_end_index

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(GenerativefirewallFlaggedSubstring, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, GenerativefirewallFlaggedSubstring):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Robust Intelligence REST API

    API methods for Robust Intelligence. Users must authenticate using the `rime-api-key` header.  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: dev@robustintelligence.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class TestrunresultTestRunMetrics(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'model_perf': 'dict(str, TestRunMetricsModelPerfMetric)',
        'average_prediction': 'float',
        'num_inputs': 'str',
        'num_failing_inputs': 'str',
        'duration_millis': 'str',
        'severity_counts': 'RimeSeverityCounts',
        'summary_counts': 'TestrunresultResultSummaryCounts',
        'category_summary_metrics': 'list[TestRunMetricsCategorySummaryMetric]',
        'risk_scores': 'list[RiskscoreRiskScore]'
    }

    attribute_map = {
        'model_perf': 'modelPerf',
        'average_prediction': 'averagePrediction',
        'num_inputs': 'numInputs',
        'num_failing_inputs': 'numFailingInputs',
        'duration_millis': 'durationMillis',
        'severity_counts': 'severityCounts',
        'summary_counts': 'summaryCounts',
        'category_summary_metrics': 'categorySummaryMetrics',
        'risk_scores': 'riskScores'
    }

    def __init__(self, model_perf=None, average_prediction=None, num_inputs=None, num_failing_inputs=None, duration_millis=None, severity_counts=None, summary_counts=None, category_summary_metrics=None, risk_scores=None):  # noqa: E501
        """TestrunresultTestRunMetrics - a model defined in Swagger"""  # noqa: E501
        self._model_perf = None
        self._average_prediction = None
        self._num_inputs = None
        self._num_failing_inputs = None
        self._duration_millis = None
        self._severity_counts = None
        self._summary_counts = None
        self._category_summary_metrics = None
        self._risk_scores = None
        self.discriminator = None
        if model_perf is not None:
            self.model_perf = model_perf
        if average_prediction is not None:
            self.average_prediction = average_prediction
        if num_inputs is not None:
            self.num_inputs = num_inputs
        if num_failing_inputs is not None:
            self.num_failing_inputs = num_failing_inputs
        if duration_millis is not None:
            self.duration_millis = duration_millis
        if severity_counts is not None:
            self.severity_counts = severity_counts
        if summary_counts is not None:
            self.summary_counts = summary_counts
        if category_summary_metrics is not None:
            self.category_summary_metrics = category_summary_metrics
        if risk_scores is not None:
            self.risk_scores = risk_scores

    @property
    def model_perf(self):
        """Gets the model_perf of this TestrunresultTestRunMetrics.  # noqa: E501

        The model performance over the test run as computed using various metrics.  # noqa: E501

        :return: The model_perf of this TestrunresultTestRunMetrics.  # noqa: E501
        :rtype: dict(str, TestRunMetricsModelPerfMetric)
        """
        return self._model_perf

    @model_perf.setter
    def model_perf(self, model_perf):
        """Sets the model_perf of this TestrunresultTestRunMetrics.

        The model performance over the test run as computed using various metrics.  # noqa: E501

        :param model_perf: The model_perf of this TestrunresultTestRunMetrics.  # noqa: E501
        :type: dict(str, TestRunMetricsModelPerfMetric)
        """

        self._model_perf = model_perf

    @property
    def average_prediction(self):
        """Gets the average_prediction of this TestrunresultTestRunMetrics.  # noqa: E501

        The average prediction for the test run (only defined for a subset of tasks such as binary classification).  # noqa: E501

        :return: The average_prediction of this TestrunresultTestRunMetrics.  # noqa: E501
        :rtype: float
        """
        return self._average_prediction

    @average_prediction.setter
    def average_prediction(self, average_prediction):
        """Sets the average_prediction of this TestrunresultTestRunMetrics.

        The average prediction for the test run (only defined for a subset of tasks such as binary classification).  # noqa: E501

        :param average_prediction: The average_prediction of this TestrunresultTestRunMetrics.  # noqa: E501
        :type: float
        """

        self._average_prediction = average_prediction

    @property
    def num_inputs(self):
        """Gets the num_inputs of this TestrunresultTestRunMetrics.  # noqa: E501

        The number of inputs. For tabular data, an input is one row.  # noqa: E501

        :return: The num_inputs of this TestrunresultTestRunMetrics.  # noqa: E501
        :rtype: str
        """
        return self._num_inputs

    @num_inputs.setter
    def num_inputs(self, num_inputs):
        """Sets the num_inputs of this TestrunresultTestRunMetrics.

        The number of inputs. For tabular data, an input is one row.  # noqa: E501

        :param num_inputs: The num_inputs of this TestrunresultTestRunMetrics.  # noqa: E501
        :type: str
        """

        self._num_inputs = num_inputs

    @property
    def num_failing_inputs(self):
        """Gets the num_failing_inputs of this TestrunresultTestRunMetrics.  # noqa: E501

        The number of failing inputs.  # noqa: E501

        :return: The num_failing_inputs of this TestrunresultTestRunMetrics.  # noqa: E501
        :rtype: str
        """
        return self._num_failing_inputs

    @num_failing_inputs.setter
    def num_failing_inputs(self, num_failing_inputs):
        """Sets the num_failing_inputs of this TestrunresultTestRunMetrics.

        The number of failing inputs.  # noqa: E501

        :param num_failing_inputs: The num_failing_inputs of this TestrunresultTestRunMetrics.  # noqa: E501
        :type: str
        """

        self._num_failing_inputs = num_failing_inputs

    @property
    def duration_millis(self):
        """Gets the duration_millis of this TestrunresultTestRunMetrics.  # noqa: E501

        The duration of the test run in milliseconds.  # noqa: E501

        :return: The duration_millis of this TestrunresultTestRunMetrics.  # noqa: E501
        :rtype: str
        """
        return self._duration_millis

    @duration_millis.setter
    def duration_millis(self, duration_millis):
        """Sets the duration_millis of this TestrunresultTestRunMetrics.

        The duration of the test run in milliseconds.  # noqa: E501

        :param duration_millis: The duration_millis of this TestrunresultTestRunMetrics.  # noqa: E501
        :type: str
        """

        self._duration_millis = duration_millis

    @property
    def severity_counts(self):
        """Gets the severity_counts of this TestrunresultTestRunMetrics.  # noqa: E501


        :return: The severity_counts of this TestrunresultTestRunMetrics.  # noqa: E501
        :rtype: RimeSeverityCounts
        """
        return self._severity_counts

    @severity_counts.setter
    def severity_counts(self, severity_counts):
        """Sets the severity_counts of this TestrunresultTestRunMetrics.


        :param severity_counts: The severity_counts of this TestrunresultTestRunMetrics.  # noqa: E501
        :type: RimeSeverityCounts
        """

        self._severity_counts = severity_counts

    @property
    def summary_counts(self):
        """Gets the summary_counts of this TestrunresultTestRunMetrics.  # noqa: E501


        :return: The summary_counts of this TestrunresultTestRunMetrics.  # noqa: E501
        :rtype: TestrunresultResultSummaryCounts
        """
        return self._summary_counts

    @summary_counts.setter
    def summary_counts(self, summary_counts):
        """Sets the summary_counts of this TestrunresultTestRunMetrics.


        :param summary_counts: The summary_counts of this TestrunresultTestRunMetrics.  # noqa: E501
        :type: TestrunresultResultSummaryCounts
        """

        self._summary_counts = summary_counts

    @property
    def category_summary_metrics(self):
        """Gets the category_summary_metrics of this TestrunresultTestRunMetrics.  # noqa: E501

        The list of category summary metrics.  # noqa: E501

        :return: The category_summary_metrics of this TestrunresultTestRunMetrics.  # noqa: E501
        :rtype: list[TestRunMetricsCategorySummaryMetric]
        """
        return self._category_summary_metrics

    @category_summary_metrics.setter
    def category_summary_metrics(self, category_summary_metrics):
        """Sets the category_summary_metrics of this TestrunresultTestRunMetrics.

        The list of category summary metrics.  # noqa: E501

        :param category_summary_metrics: The category_summary_metrics of this TestrunresultTestRunMetrics.  # noqa: E501
        :type: list[TestRunMetricsCategorySummaryMetric]
        """

        self._category_summary_metrics = category_summary_metrics

    @property
    def risk_scores(self):
        """Gets the risk_scores of this TestrunresultTestRunMetrics.  # noqa: E501

        The list of risk scores.  # noqa: E501

        :return: The risk_scores of this TestrunresultTestRunMetrics.  # noqa: E501
        :rtype: list[RiskscoreRiskScore]
        """
        return self._risk_scores

    @risk_scores.setter
    def risk_scores(self, risk_scores):
        """Sets the risk_scores of this TestrunresultTestRunMetrics.

        The list of risk scores.  # noqa: E501

        :param risk_scores: The risk_scores of this TestrunresultTestRunMetrics.  # noqa: E501
        :type: list[RiskscoreRiskScore]
        """

        self._risk_scores = risk_scores

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(TestrunresultTestRunMetrics, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TestrunresultTestRunMetrics):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
